Learn R Programming

covid19brazil (version 0.1.0)

brazil_total: The dataset with information about the new Coronavirus (COVID-19) for Brazil

Description

Daily information about the new Coronavirus (COVID-19) pandemic in Brazil

Usage

brazil_total

Arguments

Value

load the database for the current environment

Format

A data.frame object

Details

The dataset contains the daily summary of the Coronavirus pandemic cases in Brazil. The data includes the following fields:

* region - String. Indicates the country of coverage

* date - Date. Ocurrence notification date

* epidWeek - Numeric. Epidemiological week of ocurrence by notification date

* population - Numeric. Population size at the date of ocurrence notification

* accumCases - Numeric. Cumulative cases of COVID-19 by notification date

* newCases - Numeric. Number of new COVID-19 cases by notification date

* accumDeaths - Numeric. Accumulated COVID-19 deaths by notification date

* newDeaths - Numeric. Number of new COVID-19 deaths by notification date

* newRecov - Numeric. Number of new recovered COVID-19 patients by notification date

* followUp - Numeric. Number of new COVID-19 cases being followed up by notification date

Examples

Run this code
# NOT RUN {
data (brazil_total)

# }

Run the code above in your browser using DataLab